@@ -11,6 +11,17 @@ test_that("Stratigraphic scales", {
   expect_is(scale_fill_stratigraphy(), "ScaleDiscrete")
 })
 
+test_that("land classification", {
+  expect_is(scale_colour_land(), "ggproto")
+  expect_is(scale_colour_land(), "ScaleDiscrete")
+
+  expect_is(scale_color_land(), "ggproto")
+  expect_is(scale_color_land(), "ScaleDiscrete")
+
+  expect_is(scale_fill_land(), "ggproto")
+  expect_is(scale_fill_land(), "ScaleDiscrete")
+})
+
 test_that("Soil scales", {
   expect_is(scale_colour_soil(), "ggproto")
   expect_is(scale_colour_soil(), "ScaleDiscrete")
